OpenPKG CVS Repository
http://cvs.openpkg.org/
____________________________________________________________________________
Server: cvs.openpkg.org Name: Ralf S. Engelschall
Root: /e/openpkg/cvs Email: [EMAIL PROTECTED]
Module: openpkg-tools Date: 10-Apr-2004 10:28:34
Branch: HEAD Handle: 2004041009283400
Modified files:
openpkg-tools/cmd dev.sh
Log:
rename rc from ~/.openpkg-dev.rc to ~/openpkg/dev.rc
Summary:
Revision Changes Path
1.10 +9 -3 openpkg-tools/cmd/dev.sh
____________________________________________________________________________
patch -p0 <<'@@ .'
Index: openpkg-tools/cmd/dev.sh
============================================================================
$ cvs diff -u -r1.9 -r1.10 dev.sh
--- openpkg-tools/cmd/dev.sh 10 Apr 2004 08:24:36 -0000 1.9
+++ openpkg-tools/cmd/dev.sh 10 Apr 2004 08:28:34 -0000 1.10
@@ -83,11 +83,17 @@
# output as "HEAD_STICKY" which means that this becomes a third
# "hardcoded" pseudotag.
# override configuration from ${HOME}/.openpkg-dev.rc
if [ -f ${HOME}/.openpkg-dev.rc ]; then
+ echo "openpkg:dev:WARNING: legacy ~/.openpkg-dev.rc found (please rename to
~/.openpkg/dev.rc)" 1>&2
. ${HOME}/.openpkg-dev.rc
fi
+# override configuration from ${HOME}/.openpkg/dev.rc (OFFICIAL)
+if [ -f ${HOME}/.openpkg/dev.rc ]; then
+ . ${HOME}/.openpkg/dev.rc
+fi
+
# override configuration from command line
verbose=0
quiet=0
@@ -1142,7 +1148,7 @@
echo "${OPENPKG_DIST}" | ${EGREP} "/current/SRC/?$" >/dev/null 2>&1
if [ $? -eq 0 ]; then
warn "deprecated suffix /current/src in
OPENPKG_DIST=${OPENPKG_DIST}."
- warn "This might come from your ~/.openpkg-dev.rc file. Please fix."
+ warn "This might come from your ~/.openpkg/dev.rc file. Please fix."
warn "Three second penalty :-)"
sleep 3
OPENPKG_DIST=`echo ${OPENPKG_DIST} | sed -e 's;/$;;' -e
's;/current/SRC$;;'`
@@ -1150,7 +1156,7 @@
if [ ".${OPENPKG_WILD}" != . ]; then
warn "deprecated use of OPENPKG_WILD. Do not use it."
warn "Please list all instances in OPENPKG_INST (space delimited)."
- warn "This might come from your ~/.openpkg-dev.rc file. Please fix."
+ warn "This might come from your ~/.openpkg/dev.rc file. Please fix."
warn "Three second penalty :-)"
sleep 3
fi
@@ .
______________________________________________________________________
The OpenPKG Project www.openpkg.org
CVS Repository Commit List [EMAIL PROTECTED]
@@ -83,11 +83,17 @@
# output as "HEAD_STICKY" which means that this becomes a third
# "hardcoded" pseudotag.
-# override configuration from ${HOME}/.openpkg-dev.rc
+# override configuration from ${HOME}/.openpkg-dev.rc (LEGACY)
if [ -f ${HOME}/.openpkg-dev.rc ]; then